**Example 1: 示例1**



Input: 

```
tccli keewidb DestroyPrepaidInstance --cli-unfold-argument  \
    --InstanceId kee-ldmm****
```

Output: 
```
{
    "Response": {
        "DealId": "229125413",
        "RequestId": "6094d5ee-84ae-4bd3-8b76-ead8bdd2986d"
    }
}
```

